<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
<context>
    <name>CloseConfirmDialog</name>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="61"/>
        <source>Please select your operation</source>
        <translation>Valitse toiminto</translation>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="68"/>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="70"/>
        <source>Minimize to system tray</source>
        <translation>Minimoi valikkoon</translation>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="79"/>
        <source>Do not ask again</source>
        <translation>Älä kysy uudestaan</translation>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="90"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="91"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Footer</name>
    <message>
        <location filename="../view/footerwidget.cpp" line="290"/>
        <source>Previous</source>
        <translation>Edellinen</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="291"/>
        <source>Next</source>
        <translation>Seuraava</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="292"/>
        <source>Play/Pause</source>
        <translation>Toista/Keskeytä</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="293"/>
        <source>Favorite</source>
        <translation>Suosikki</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="294"/>
        <source>Lyrics</source>
        <translation>Sanat</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="239"/>
        <source>Unknown Title</source>
        <translation>Tuntematon nimi</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="245"/>
        <location filename="../view/footerwidget.cpp" line="536"/>
        <location filename="../view/footerwidget.cpp" line="718"/>
        <source>Unknown artist</source>
        <translation>Tuntematon artisti</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="295"/>
        <source>Play Mode</source>
        <translation>Toistotila</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="296"/>
        <source>Playlist</source>
        <translation>Soittolista</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="696"/>
        <source>List Loop</source>
        <translation>Musiikkilistan silmukka</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="699"/>
        <source>Single Loop</source>
        <translation>Silmukka</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="702"/>
        <source>Shuffle</source>
        <translation>Sekoitta</translation>
    </message>
</context>
<context>
    <name>ImportWidget</name>
    <message>
        <location filename="../view/importwidget.cpp" line="73"/>
        <source>Add folder</source>
        <translation>Lisää kansio</translation>
    </message>
    <message>
        <location filename="../view/importwidget.cpp" line="79"/>
        <location filename="../view/importwidget.cpp" line="120"/>
        <source>Scan</source>
        <translation>Skannaa</translation>
    </message>
    <message>
        <location filename="../view/importwidget.cpp" line="80"/>
        <location filename="../view/importwidget.cpp" line="121"/>
        <source>%1 music directory or drag &amp; drop music file to add music</source>
        <translation>%1 musiikkikansio lisää musiikkia vetämällä tai pudottamalla</translation>
    </message>
    <message>
        <location filename="../view/importwidget.cpp" line="112"/>
        <source>Loading music, please wait...</source>
        <translation>Lataa musiikkia, odota ...</translation>
    </message>
</context>
<context>
    <name>InfoDialog</name>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="117"/>
        <source>Title:</source>
        <translation>Otsikko:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="117"/>
        <source>Artist:</source>
        <translation>Artisti:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="118"/>
        <source>Album:</source>
        <translation>Albumi:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="118"/>
        <source>Type:</source>
        <translation>Tyyppi:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="120"/>
        <source>Path:</source>
        <translation>Polku:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="192"/>
        <source>Unknown artist</source>
        <translation>Tuntematon artisti</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="193"/>
        <source>Unknown album</source>
        <translation>Tuntematon albumi</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="119"/>
        <source>Size:</source>
        <translation>Koko:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="119"/>
        <source>Duration:</source>
        <translation>Kesto:</translation>
    </message>
</context>
<context>
    <name>LoadWidget</name>
    <message>
        <location filename="../view/loadwidget.cpp" line="43"/>
        <source>Loading...</source>
        <translation>Lataa...</translation>
    </message>
</context>
<context>
    <name>LyricWidget</name>
    <message>
        <location filename="../view/lyricwidget.cpp" line="166"/>
        <source>Find lyrics</source>
        <translation>Etsi sanoitukset</translation>
    </message>
    <message>
        <location filename="../view/lyricwidget.cpp" line="170"/>
        <source>Title</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../view/lyricwidget.cpp" line="175"/>
        <source>Artist</source>
        <translation>Esittäjä</translation>
    </message>
    <message>
        <location filename="../view/lyricwidget.cpp" line="180"/>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <location filename="../view/lyricwidget.cpp" line="213"/>
        <source>Back</source>
        <translation>Takaisin</translation>
    </message>
</context>
<context>
    <name>MainFrame</name>
    <message>
        <location filename="../view/mainframe.cpp" line="136"/>
        <source>New playlist</source>
        <translation>Uusi soittolista</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="152"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="183"/>
        <location filename="../view/mainframe.cpp" line="595"/>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="142"/>
        <source>Add folder</source>
        <translation>Lisää kansio</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="147"/>
        <source>Add file</source>
        <translation>Lisää tiedosto</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="168"/>
        <source>Dark theme</source>
        <translation>Tumma teema</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="254"/>
        <source>Deepin Music is a beautiful and simple music player that plays local audios. It supports viewing lyrics during playback, playing lossless audio and playlist customization, etc.</source>
        <translation>Deepin Music on kaunis ja yksinkertainen musiikkisoitin, joka toistaa kiintolevysi paikallista musiikkia. Se tukee sanoitusten näyttämistä toiston aikana, häviöttömän äänen ja soittolistan muokkaamista jne.</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="592"/>
        <source>Play/Pause</source>
        <translation>Toista/Keskeytä</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="593"/>
        <source>Previous</source>
        <translation>Edellinen</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="739"/>
        <source>Invalid or non-existent file</source>
        <translation>Virheellinen tai olematon tiedosto</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="760"/>
        <source>Failed to import, no vaild music file found!</source>
        <translation>Tuonti epäonnistui, musiikkitiedostoa ei löytynyt!</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="1027"/>
        <source>All music</source>
        <translation>Kaikki musiikki</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="740"/>
        <location filename="../view/mainframe.cpp" line="765"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="690"/>
        <source>Successfully added to &quot;%1&quot;</source>
        <translation>Lisätty onnistuneesti osoitteeseen &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="594"/>
        <source>Next</source>
        <translation>Seuraava</translation>
    </message>
</context>
<context>
    <name>MusicListView</name>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="295"/>
        <source>New playlist</source>
        <translation>Uusi soittolista</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="335"/>
        <source>Play</source>
        <translation>Toista</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="337"/>
        <source>Add to playlist</source>
        <translation>Lisää soittolistaan</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="342"/>
        <source>Display in file manager</source>
        <translation>Näytä tiedostonhallinnassa</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="369"/>
        <source>Song info</source>
        <translation>Kappaleen tiedot</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="425"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Haluatko varmasti poistaa %1?</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="427"/>
        <location filename="../view/widget/musiclistview.cpp" line="431"/>
        <source>Are you sure you want to delete the selected %1 songs?</source>
        <translation>Haluatko varmasti poistaa valitut %1 kappaleet?</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="345"/>
        <source>Remove from playlist</source>
        <translation>Poista soittolistalta</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="346"/>
        <source>Delete from local disk</source>
        <translation>Poista paikalliselta levyltä</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="365"/>
        <source>Encoding</source>
        <translation>Tavuesitys</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="415"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="416"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="432"/>
        <source>Deleting the current song will also delete the song files contained</source>
        <translation>Nykyisen kappaleen poistaminen poistaa myös lauluun sisältyvät tiedostot</translation>
    </message>
    <message>
        <location filename="../view/widget/delegate/musicitemdelegate.cpp" line="299"/>
        <source>Unknown artist</source>
        <translation>Tuntematon artisti</translation>
    </message>
    <message>
        <location filename="../view/widget/delegate/musicitemdelegate.cpp" line="310"/>
        <source>Unknown album</source>
        <translation>Tuntematon albumi</translation>
    </message>
</context>
<context>
    <name>MusicListWidget</name>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="140"/>
        <source>No Music</source>
        <translation>Ei musiikkia</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="142"/>
        <source>No result found</source>
        <translation>Tuloksia ei löytynyt</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="174"/>
        <source>Play All</source>
        <translation>Toista kaikki</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="182"/>
        <source>Time added</source>
        <translation>Lisätty aika</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="183"/>
        <source>Title</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="184"/>
        <source>Artist</source>
        <translation>Esittäjä</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="185"/>
        <source>Album name</source>
        <translation>Albumin nimi</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="217"/>
        <source>Custom</source>
        <translation>Kustomoitu</translation>
    </message>
</context>
<context>
    <name>PlayListItem</name>
    <message>
        <location filename="../view/widget/playlistitem.cpp" line="187"/>
        <source>Are you sure you want to delete this playlist?</source>
        <translation>Haluatko varmasti poistaa tämän soittolistan?</translation>
    </message>
    <message>
        <location filename="../view/widget/playlistitem.cpp" line="194"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../view/widget/playlistitem.cpp" line="193"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
</context>
<context>
    <name>PlayListView</name>
    <message>
        <location filename="../view/widget/playlistview.cpp" line="186"/>
        <location filename="../view/widget/playlistview.cpp" line="195"/>
        <source>Play</source>
        <translation>Toista</translation>
    </message>
    <message>
        <location filename="../view/widget/playlistview.cpp" line="190"/>
        <location filename="../view/widget/playlistview.cpp" line="198"/>
        <source>Rename</source>
        <translation>Nimeä uudestaan</translation>
    </message>
    <message>
        <location filename="../view/widget/playlistview.cpp" line="191"/>
        <location filename="../view/widget/playlistview.cpp" line="202"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>PlaylistManager</name>
    <message>
        <location filename="../core/playlistmanager.cpp" line="79"/>
        <source>New playlist</source>
        <translation>Uusi soittolista</translation>
    </message>
    <message>
        <location filename="../core/playlistmanager.cpp" line="135"/>
        <source>All Music</source>
        <translation>Kaikki musiikki</translation>
    </message>
    <message>
        <location filename="../core/playlistmanager.cpp" line="141"/>
        <source>My favorites</source>
        <translation>Minun suosikit</translation>
    </message>
    <message>
        <location filename="../core/playlistmanager.cpp" line="147"/>
        <source>Search result</source>
        <translation>Hakutulokset</translation>
    </message>
</context>
<context>
    <name>PlaylistWidget</name>
    <message>
        <location filename="../view/playlistwidget.cpp" line="58"/>
        <source>New playlist</source>
        <translation>Uusi soittolista</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../view/mainframe.cpp" line="256"/>
        <source>Deepin Music</source>
        <translation>Deepin Musiikki</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="87"/>
        <source>Deepin Music</source>
        <translation>Deepin Musiikki</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="26"/>
        <source>Minimize to system tray</source>
        <translation>Minimoi valikkoon</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="27"/>
        <source>Exit Deepin Music</source>
        <translation>Poistu Deepin musiikista</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="28"/>
        <source>Autoplay</source>
        <translation>Automaattitoisto</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="29"/>
        <source>Enable fade in/out</source>
        <translation>Salli häivytys</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="30"/>
        <source>Remember playback position</source>
        <translation>Muista toiston sijainti</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="31"/>
        <source>Close Main Window</source>
        <translation>Sulje pääikkuna</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="32"/>
        <source>Basic</source>
        <translation>Perusasetukset</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="33"/>
        <source>Play</source>
        <translation>Toista</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="34"/>
        <source>Shortcuts</source>
        <translation>Pikanäppäimet</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="35"/>
        <source>Restore Defaults</source>
        <translation>Palauta oletukset</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="36"/>
        <source>Next</source>
        <translation>Seuraava</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="37"/>
        <source>Play/Pause</source>
        <translation>Toista/Keskeytä</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="38"/>
        <source>Previous</source>
        <translation>Edellinen</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="39"/>
        <source>Volume down</source>
        <translation>Volyymi alas</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="40"/>
        <source>Volume up</source>
        <translation>Volyymi ylös</translation>
    </message>
</context>
<context>
    <name>SearchResult</name>
    <message>
        <location filename="../view/widget/searchresult.cpp" line="57"/>
        <location filename="../view/widget/searchresult.cpp" line="126"/>
        <source>Search &quot;%1&quot; in Deepin Music</source>
        <translation>Hae &quot;%1&quot; Deepin musiikista</translation>
    </message>
</context>
<context>
    <name>TitlebarWidget</name>
    <message>
        <location filename="../view/widget/titlebarwidget.cpp" line="90"/>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
</context>
</TS>